@@ -6,7 +6,7 @@ pub use mem::*;
 mod tests {
     
     #[test]
-    fn test_immutable() {
+    fn test_immut() {
         use crate::*;
 
         fn test_new() {
