@@ -2,19 +2,19 @@ pub use super::*;
 
 pub type Byte = u128;
 
-pub struct Immutable {
+pub struct Immut {
     memory: Vec<Byte>
 }
 
-impl Immutable {
-    pub fn new(size: usize) -> Immutable {
-        Immutable {
+impl Immut {
+    pub fn new(size: usize) -> Immut {
+        Immut {
             memory: vec![0x0; size]
         }
     }
 
-    pub fn from(memory: Vec<Byte>) -> Immutable {
-        Immutable {
+    pub fn from(memory: Vec<Byte>) -> Immut {
+        Immut {
             memory
         }
     }
